@@ -1,5 +1,5 @@
 package Bio::Roary::CommandLine::QueryRoary;
-$Bio::Roary::CommandLine::QueryRoary::VERSION = '3.0.1';
+$Bio::Roary::CommandLine::QueryRoary::VERSION = '3.0.2';
 # ABSTRACT: Take in a groups file and the protein fasta files and output selected data
 
 
@@ -26,7 +26,7 @@ has 'input_set_one'   => ( is => 'rw', isa => 'ArrayRef' );
 has 'input_set_two'   => ( is => 'rw', isa => 'ArrayRef' );
 has 'output_filename' => ( is => 'rw', isa => 'Str', default => 'pan_genome_results' );
 has 'action'          => ( is => 'rw', isa => 'Str', default => 'union' );
-has 'core_definition' => ( is => 'rw', isa => 'Num', default => 1.0 );
+has 'core_definition' => ( is => 'rw', isa => 'Num', default => 0.99 );
 
 has '_error_message' => ( is => 'rw', isa => 'Str' );
 
@@ -51,7 +51,7 @@ sub BUILD {
     
     $self->output_filename($output_filename) if ( defined($output_filename) );
     $self->action($action)                   if ( defined($action) );
-    $self->core_definition($core_definition) if ( defined($core_definition) );
+	$self->core_definition( $core_definition / 100 ) if ( defined($core_definition) );
     if ( defined($groups_filename) && ( -e $groups_filename ) ) {
         $self->groups_filename($groups_filename);
     }
@@ -157,7 +157,7 @@ sub run {
       
       for my $differences_group_filename(($difference_between_sets->groups_set_one_unique_filename,$difference_between_sets->groups_set_two_unique_filename,$difference_between_sets->groups_in_common_filename))
       {
-        $self->create_spreadsheets($differences_group_filename, $prepare_input_files->fasta_files, $prepare_input_files->fasta_files);
+        $self->create_spreadsheets($differences_group_filename, $prepare_input_files->fasta_files, $self->input_files);
       }
 
     }
@@ -186,6 +186,10 @@ sub create_spreadsheets
       my $order_genes_obj = Bio::Roary::OrderGenes->new(
         analyse_groups_obj => $analyse_groups_obj,
         gff_files          => $gff_files,
+		core_definition    => $self->core_definition,
+		pan_graph_filename => 'set_difference_core_accessory_graph.dot',
+		accessory_graph_filename  => 'set_difference_accessory_graph.dot',
+		
       );
       
       my $group_statistics = Bio::Roary::GroupStatistics->new(
@@ -204,23 +208,26 @@ sub usage_text {
     Usage: query_pan_genome [options]
     Take in a groups file and GFF files and output selected data
     
-    # Provide an output filename
-    query_pan_genome  -a union -g clustered_proteins -o results.fa *.gff
-    
     # Create multifasta files for each group/gene passed in
-    query_pan_genome  -a gene_multifasta -g clustered_proteins -n gryA,mecA,abc *.gff
+    query_pan_genome -a gene_multifasta -n gryA,mecA,abc *.gff
     
     # Union
-    query_pan_genome  -a union -g clustered_proteins *.gff
+    query_pan_genome -a union *.gff
     
     # Intersection
-    query_pan_genome  -a intersection -g clustered_proteins *.gff
+    query_pan_genome -a intersection *.gff
 
     # Complement (Union minus Intersection)
-    query_pan_genome  -a complement -g clustered_proteins *.gff
+    query_pan_genome -a complement *.gff
     
     # Difference between sets 
-    query_pan_genome  -a difference --input_set_one 1.gff,2.gff --input_set_two 3.gff,4.gff,5.gff  -g clustered_proteins
+    query_pan_genome -a difference --input_set_one 1.gff,2.gff --input_set_two 3.gff,4.gff,5.gff
+
+    # Provide an output filename
+    query_pan_genome -a union -o results.fa *.gff
+	
+    # Change the core definition to 95%, default is a gene must be in 99% of isolates to be core
+    query_pan_genome -a union -c 95 *.gff
 
     # This help message
     query_pan_genome -h
@@ -244,7 +251,7 @@ Bio::Roary::CommandLine::QueryRoary - Take in a groups file and the protein fast
 
 =head1 VERSION
 
-version 3.0.1
+version 3.0.2
 
 =head1 SYNOPSIS
 
