@@ -1,6 +1,6 @@
 
 package Bio::Roary::Output::GroupsMultifastasNucleotide;
-$Bio::Roary::Output::GroupsMultifastasNucleotide::VERSION = '3.0.1';
+$Bio::Roary::Output::GroupsMultifastasNucleotide::VERSION = '3.0.2';
 # ABSTRACT:  Take in a set of GFF files and a groups file and output one multifasta file per group with nucleotide sequences.
 
 
@@ -14,6 +14,8 @@ has 'gff_files'        => ( is => 'ro', isa => 'ArrayRef',
 has 'group_names'      => ( is => 'ro', isa => 'ArrayRef',                      required => 0 );
 has 'annotate_groups'  => ( is => 'ro', isa => 'Bio::Roary::AnnotateGroups', required => 1 );
 has 'output_multifasta_files'     => ( is => 'ro', isa => 'Bool',     default  => 0 );
+has 'core_definition'  => ( is => 'ro', isa => 'Num', default  => 1.0 );
+has 'dont_delete_files' => ( is => 'ro', isa => 'Bool',     default  => 0 );
 
 has 'output_directory' => ( is => 'ro', isa => 'Str', lazy => 1, builder => '_build_output_directory');
 
@@ -45,6 +47,7 @@ sub create_files {
 
     make_path($self->output_directory);
     
+	my $number_of_gff_files = @{$self->gff_files};
 	my %pan_reference_groups_seen;
     # if its output_multifasta_files == false then you want to create the core genome and delete all intermediate multifasta files
     for my $gff_file ( @{ $self->gff_files } ) 
@@ -55,7 +58,10 @@ sub create_files {
           output_directory     => $self->output_directory,
           annotate_groups      => $self->annotate_groups,
           output_multifasta_files => $self->output_multifasta_files,
-		  pan_reference_groups_seen => \%pan_reference_groups_seen
+		  pan_reference_groups_seen => \%pan_reference_groups_seen,
+		  core_definition      => $self->core_definition,
+		  dont_delete_files    => $self->dont_delete_files,
+		  number_of_gff_files  => $number_of_gff_files
       );
       $gff_multifasta->populate_files;
     }
@@ -79,7 +85,7 @@ Bio::Roary::Output::GroupsMultifastasNucleotide - Take in a set of GFF files and
 
 =head1 VERSION
 
-version 3.0.1
+version 3.0.2
 
 =head1 SYNOPSIS
 
