@@ -1,5 +1,5 @@
 package Bio::Roary::PostAnalysis;
-$Bio::Roary::PostAnalysis::VERSION = '3.0.1';
+$Bio::Roary::PostAnalysis::VERSION = '3.0.2';
 # ABSTRACT: Post analysis of pan genomes
 
 
@@ -184,7 +184,9 @@ sub _build__groups_multifastas_nuc_obj
       gff_files       => $self->input_files,
       annotate_groups => $self->_annotate_groups_obj,
       group_names     => $self->_analyse_groups_obj->_groups,
-      group_limit     => $self->group_limit
+      group_limit     => $self->group_limit,
+	  core_definition => $self->core_definition,
+	  dont_delete     => $self->dont_delete_files
     );
 }
 
@@ -252,7 +254,7 @@ Bio::Roary::PostAnalysis - Post analysis of pan genomes
 
 =head1 VERSION
 
-version 3.0.1
+version 3.0.2
 
 =head1 SYNOPSIS
 
